==> Paws-0.01.tar.gz: Paws-0.01/lib/Paws/StorageGateway/CancelRetrieval.pm <==

package Paws::StorageGateway::CancelRetrieval {
  use Moose;
  has GatewayARN => (is => 'ro', isa => 'Str', required => 1);
  has TapeARN => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CancelRetrieval');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::StorageGateway::CancelRetrievalOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::StorageGateway::CancelRetrieval - Arguments for method CancelRetrieval on Paws::StorageGateway

=head1 DESCRIPTION

This class represents the parameters used for calling the method CancelRetrieval on the 
AWS Storage Gateway service. Use the attributes of this class
as arguments to method CancelRetrieval.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to CancelRetrieval.

As an example:

  $service_obj->CancelRetrieval(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> GatewayARN => Str

  

=head2 B<REQUIRED> TapeARN => Str

  

The Amazon Resource Name (ARN) of the virtual tape you want to cancel
retrieval for.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for CancelRetrieval in Paws::StorageGateway

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.06.tar.gz: Paws-0.06/lib/Paws/StorageGateway/CancelRetrieval.pm <==

package Paws::StorageGateway::CancelRetrieval {
  use Moose;
  has GatewayARN => (is => 'ro', isa => 'Str', required => 1);
  has TapeARN => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CancelRetrieval');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::StorageGateway::CancelRetrievalOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::StorageGateway::CancelRetrieval - Arguments for method CancelRetrieval on Paws::StorageGateway

=head1 DESCRIPTION

This class represents the parameters used for calling the method CancelRetrieval on the 
AWS Storage Gateway service. Use the attributes of this class
as arguments to method CancelRetrieval.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to CancelRetrieval.

As an example:

  $service_obj->CancelRetrieval(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> GatewayARN => Str

  

=head2 B<REQUIRED> TapeARN => Str

  

The Amazon Resource Name (ARN) of the virtual tape you want to cancel
retrieval for.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CancelRetrieval in L<Paws::StorageGateway>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
